OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalenner",
    "Individual" : "Persoun",
    "Group" : "Grupp",
    "Resource" : "Ressource",
    "Room" : "Raum",
    "Unknown" : "Onbekannt",
    "Required" : "Noutwendeg",
    "Optional" : "Fräiwëlleg",
    "Does not attend" : "Hellt net deel",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bass an enger onbekannter Zäitzone ({tz}) a fäls elo zeréck op UTC",
    "Please create a calendar first." : "W.e.g. erstell fir d'éischt en neie Kalenner.",
    "New event" : "Neit Evenement",
    "group" : "Grupp",
    "Attendees" : "Participanten",
    "Reminders" : "Erennërungen",
    "Repeating" : "Widderhëlt sech",
    "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
    "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
    "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
    "Cancelled" : "Ofgebrach",
    "Global" : "Global",
    "None" : "Keng",
    "Every day" : "All Dag",
    "Every week" : "All Woch",
    "Every month" : "All Mount",
    "Every year" : "All Joer",
    "never" : "Ni",
    "after" : "No",
    "At time of event" : "Zum Zäitpunkt vum Evenement",
    "5 minutes before" : "5 Minutte virdrun",
    "10 minutes before" : "10 Minutte virdrun",
    "15 minutes before" : "15 Minutte virdrun",
    "30 minutes before" : "30 Minutte virdrun",
    "1 hour before" : "1 Stonn virdrun",
    "2 hours before" : "2 Stonne virdrun",
    "Custom" : "Individualiséier",
    "Audio" : "Toun",
    "Pop-up" : "Pop-up",
    "sec" : "Sekonn",
    "min" : "Minutt",
    "hours" : "Stonnen",
    "days" : "Deeg",
    "week" : "Woch",
    "before" : "virdrun",
    "start" : "Start",
    "end" : "Ophalen",
    "Editing reminders of unknown type not supported." : "D'ännere vun onbekannten Typpen vun Erënnerungen gëtt net ënnerstëtzt.",
    "Week {number} of {year}" : "Woch {Nummer} vum {Joer}",
    "{type} {time} before the event starts" : "{tipp} {Zäit} éier d'Evenement ufänkt",
    "{type} {time} before the event ends" : "{tipp} {Zäit} éier d'Evenement ophält",
    "{type} {time} after the event starts" : "{tipp} {Zäit} nodeems en Evenement ufänkt ",
    "{type} {time} after the event ends" : "{tipp} {Zäit} nodeems en Evenement ophält",
    "{type} at the event's start" : "{tipp} beim Ufank vun engem Evenement ",
    "{type} at the event's end" : "{tipp} beim Enn vun engem Evenement ",
    "{type} at {time}" : "{tipp} op {Zäit}",
    "{calendar} shared by {owner}" : "{Kalenner} gedeelt vum {Besëtzer}",
    "Title of the Event" : "Titel vum Evenement",
    "All day Event" : "Ganzdaags-Evenement",
    "Delete" : "Läschen",
    "Cancel" : "Ofbriechen",
    "More ..." : "Méi...",
    "Create" : "Erstellen",
    "Update" : "Update",
    "Close" : "Zoumaachen",
    "Location" : "Uert",
    "Description" : "Beschreiwung",
    "Export" : "Exportéieren",
    "Day" : "Dag",
    "Week" : "Woch",
    "Month" : "Mount",
    "Today" : "Haut",
    "Share Calendar" : "Kalenner deelen",
    "Shared" : "Gedeelt",
    "More" : "Méi",
    "Edit" : "Änneren",
    "Link" : "Link",
    "Download" : "Eroflueden",
    "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
    "can edit" : "kann änneren",
    "New Calendar" : "Neie Kalenner",
    "Name" : "Numm",
    "New Subscription" : "Neit Abonnement",
    "Edit event" : "Evenement änneren",
    "Delete Event" : "Evenement läschen",
    "Save Event" : "Evenement späicheren",
    "Time" : "Zäit",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Widderhuelen",
    "times every" : "Zäit all",
    "Add" : "Dobäisetzen",
    "from" : "vun",
    "to" : "bis",
    "This event's repeating rule is not supported yet." : "D'Widderhuelungs Regel vun dësem Evenement gëtt nach net ënnerstëtzt.",
    "Reset repeating rule" : "D'Widderhuelungs Regel zeréck setzen",
    "Repeat every ..." : "All ... widderhuelen",
    "end repeat ..." : "widderhuelen ... ophalen",
    "times" : "mol",
    "Import Calendars" : "Kalenner importéieren",
    "Import canceled" : "Import ofgebrach",
    "Analyzing calendar" : "Kalenner analyséieren",
    "The file contains objects incompatible with the selected calendar" : "Dëse Fichier enthält Objeten déi net mam ausgelwielte Kalenner kompatibel sinn.",
    "New calendar" : "Neie Kalenner",
    "Import scheduled" : "Import geplangt",
    "Import calendar" : "Kalenner importéiren",
    "No Calendars selected for import" : "Et ass kee Kalenner fir en Import ausgewielt ginn",
    "Primary CalDAV address" : "Haapt-CalDAV-Adress",
    "iOS/OS X CalDAV address" : "iOS/OS X-CalDav-Adress"
},
"nplurals=2; plural=(n != 1);");
